Struct ZwpPrimarySelectionSourceV1
pub struct ZwpPrimarySelectionSourceV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
offer to replace the contents of the primary selection
The source side of a wp_primary_selection_offer, it provides a way to describe the offered data and respond to requests to transfer the requested contents of the primary selection clipboard.
See also the Request enum for this interface.
Implementations
impl ZwpPrimarySelectionSourceV1
impl ZwpPrimarySelectionSourceV1
pub fn send(&self, mime_type: String, fd: BorrowedFd<'_>)
pub fn send(&self, mime_type: String, fd: BorrowedFd<'_>)
send the primary selection contents
Request for the current primary selection contents from the client. Send the specified mime type over the passed file descriptor, then close it.
pub fn cancelled(&self)
pub fn cancelled(&self)
request for primary selection contents was canceled
This primary selection source is no longer valid. The client should clean up and destroy this primary selection source.